@@ -1,4 +1,5 @@
 from enum import Enum
+from arjuna.tpi.helper.arjtype import CIStringDict
 
 def repr_dict(d, replace_value_enum=False):
     def format_key(k):
@@ -15,6 +16,8 @@ def repr_dict(d, replace_value_enum=False):
                 return v.name.lower()
             else:
                 return v
+        elif isinstance(v, CIStringDict):
+            return repr_dict(v)
         else:
             return v
     return "{" + ", ".join(["{}={}".format(format_key(k), format_value(v)) for k,v in d.items()]) + "}"
\ No newline at end of file
